@@ -2,14 +2,15 @@
 
 namespace XploreBooking;
 
+use XploreBooking\Controller\JourneyController;
+use XploreBooking\Controller\TicketController;
+
 class XploreBookingPlugin
 {
 
     private $pluginDirectoryPath;
     private $pluginDirectoryURL;
-
     private $journeyController;
-    private $orderController;
     private $ticketController;
 
     public function __construct($pluginDirectoryPath, $pluginDirectoryURL)
@@ -51,16 +52,16 @@ class XploreBookingPlugin
     public function pluginActivation()
     {
         $this->createPages();
+        $this->createTickets();
+        $this->createJourneys();
     }
 
-    private function createPages()
-    {
+    private function createPages() {
         $pageDefinitions = [
             'booking' => [
-                'post_title' => 'Booking',
-            ],
+                'post_title' => 'Booking'
+            ]
         ];
-
         foreach ($pageDefinitions as $slug => $pageArgs) {
             // Check that the page doesn't exist already
             $query = new \WP_Query('pagename=' . $slug);
@@ -77,6 +78,58 @@ class XploreBookingPlugin
                 wp_insert_post($args);
             }
         }
+
+    }
+    private function createTickets()
+    {
+
+        $ticketTypes = TicketController::ticketTypes();
+
+        foreach ($ticketTypes as $slug => $pageArgs) {
+            $query = new \WP_Query('pagename=' . $slug);
+            if (!$query->have_posts()) {
+                $defaultArgs = [
+                    'post_name' => $slug,
+                    'post_status' => 'publish',
+                    'post_type' => 'ticket',
+                    'ping_status' => 'closed',
+                    'comment_status' => 'closed',
+                ];
+                $args = array_merge($pageArgs, $defaultArgs);
+                $postID = wp_insert_post($args);
+                update_field('single_cost', $pageArgs['single_cost'], $postID);
+                update_field('return_cost', $pageArgs['return_cost'], $postID);
+                update_field('advanced_single', $pageArgs['advanced_single'], $postID);
+                update_field('advanced_return', $pageArgs['advanced_return'], $postID);
+                update_field('seats', $pageArgs['seats'], $postID);
+            }
+        }
+    }
+
+    private function createJourneys()
+    {
+
+        $pageDefinitions = JourneyController::journeyTimes();
+
+        foreach ($pageDefinitions as $slug => $pageArgs) {
+            // Check that the page doesn't exist already
+            $query = new \WP_Query('pagename=' . $slug);
+            if (!$query->have_posts()) {
+                // Add the page using the data from the array above
+                $defaultArgs = [
+                    'post_name' => $slug,
+                    'post_status' => 'publish',
+                    'post_type' => 'journey',
+                    'ping_status' => 'closed',
+                    'comment_status' => 'closed',
+                ];
+                $args = array_merge($pageArgs, $defaultArgs);
+                wp_insert_post($args);
+                $postID = wp_insert_post($args);
+                update_field('departure_time', $pageArgs['departure_time'], $postID);
+                update_field('arrival_time', $pageArgs['departure_time'], $postID);
+            }
+        }
     }
 
     public function enqueueAssets()
@@ -111,6 +164,7 @@ class XploreBookingPlugin
     public function registerPostType()
     {
         Post\Journey::registerPostType();
+        Post\JourneyDate::registerPostType();
         Post\Booking::registerPostType();
         Post\Ticket::registerPostType();
     }
